@@ -78,7 +78,7 @@ _CLI_OPTS = [
     cfg.BoolOpt('keep', default=False,
                 deprecated_group='kolla-build',
                 help='Keep failed intermediate containers'),
-    cfg.StrOpt('namespace', short='n', default='kolla',
+    cfg.StrOpt('namespace', short='n', default='kollaglue',
                deprecated_group='kolla-build',
                help='The Docker namespace name'),
     cfg.BoolOpt('cache', default=True,
@@ -160,63 +160,63 @@ SOURCES = {
     'ceilometer-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/ceilometer/'
-                     'ceilometer-5.0.2.tar.gz')},
+                     'ceilometer-6.0.0.tar.gz')},
     'cinder-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/cinder/'
-                     'cinder-7.0.2.tar.gz')},
+                     'cinder-8.0.0.tar.gz')},
     'designate-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/designate/'
-                     'designate-1.0.2.tar.gz')},
+                     'designate-2.0.0.tar.gz')},
     'glance-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/glance/'
-                     'glance-11.0.1.tar.gz')},
+                     'glance-12.0.0.tar.gz')},
     'gnocchi-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/gnocchi/'
-                     'gnocchi-1.3.5.tar.gz')},
+                     'gnocchi-2.1.0.tar.gz')},
     'heat-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/heat/'
-                     'heat-5.0.1.tar.gz')},
+                     'heat-6.0.0.tar.gz')},
     'horizon': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/horizon/'
-                     'horizon-8.0.1.tar.gz')},
+                     'horizon-9.0.0.tar.gz')},
     'ironic-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/ironic/'
-                     'ironic-4.3.0.tar.gz')},
+                     'ironic-5.1.0.tar.gz')},
     'keystone': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/keystone/'
-                     'keystone-8.1.0.tar.gz')},
+                     'keystone-9.0.0.tar.gz')},
     'magnum-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/magnum/'
-                     'magnum-1.1.0.tar.gz')},
+                     'magnum-2.0.0.tar.gz')},
     'manila-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/manila/'
-                     'manila-1.0.1.tar.gz')},
+                     'manila-2.0.0.tar.gz')},
     'mistral-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/mistral/'
-                     'mistral-1.0.1.tar.gz')},
+                     'mistral-2.0.0.tar.gz')},
     'murano-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/murano/'
-                     'murano-1.0.2.tar.gz')},
+                     'murano-2.0.0.tar.gz')},
     'neutron-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/neutron/'
-                     'neutron-7.0.4.tar.gz')},
+                     'neutron-8.0.0.tar.gz')},
     'nova-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/nova/'
-                     'nova-12.0.3.tar.gz')},
+                     'nova-13.0.0.tar.gz')},
     'nova-spicehtml5proxy': {
         'type': 'url',
         'location': ('http://github.com/SPICE/spice-html5/tarball/'
@@ -228,7 +228,7 @@ SOURCES = {
     'swift-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/swift/'
-                     'swift-2.5.0.tar.gz')},
+                     'swift-2.7.0.tar.gz')},
     'tempest': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/tempest/'
@@ -236,11 +236,11 @@ SOURCES = {
     'trove-base': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/trove/'
-                     'trove-4.0.0.tar.gz')},
+                     'trove-5.0.0.tar.gz')},
     'zaqar': {
         'type': 'url',
         'location': ('http://tarballs.openstack.org/zaqar/'
-                     'zaqar-1.0.0.tar.gz')}
+                     'zaqar-2.0.0.tar.gz')}
 
 }
 
